2
0

SWDEV-470698 - fix formatting, add format check workflow (#657)

Este cometimento está contido em:
Danylo Lytovchenko
2025-08-20 16:28:06 +02:00
cometido por GitHub
ascendente 5840940caa
cometimento f7338717ae
1574 ficheiros modificados com 162972 adições e 199346 eliminações
+1 -2
Ver ficheiro
@@ -18,7 +18,6 @@ THE SOFTWARE.
*/
#include "hip/hip_runtime.h"
extern "C" __global__ void Add(int* a, int* b, int* c) {
size_t tx = (blockIdx.x * blockDim.x + threadIdx.x);
size_t tx = (blockIdx.x * blockDim.x + threadIdx.x);
c[tx] = a[tx] + b[tx];
}